﻿
using DXHelper;
using Microsoft.Win32;
using System;
using System.Text;

namespace fifasetup_csharp
{
  public class DetectWeakCPU
  {
    private string VendorIdentifier;
    private string ProcessorNameString;
    private uint ProcessorMHZ;
    private uint NumLogicalProcessors;
    private uint NumPhysicalCores;
    private bool IsIntel;
    private bool IsAMD;
    private float Score;
    public string ScoreDebugString;
    public float Debug_lowScore;
    public float Debug_highScore;
    public float Debug_processorMhz;
    public float Debug_mhzInterpolator;
    public float Debug_coresScaleFactor;
    private float ScoreTemp_LowScore;
    private float ScoreTemp_HighScore;
    private float ScoreTemp_LowMHZ;
    private float ScoreTemp_HighMHZ;

    protected static string ReadStringRegistryKey(
      string keyName,
      string valueName,
      string defaultValue = null)
    {
      string str = (string) null;
      try
      {
        str = Registry.GetValue(keyName, valueName, (object) null) as string;
      }
      catch (Exception ex)
      {
      }
      return str ?? defaultValue;
    }

    protected static uint ReadDwordRegistryKey(string keyName, string valueName, uint defaultValue = 0)
    {
      try
      {
        object obj = Registry.GetValue(keyName, valueName, (object) null);
        if (obj is int)
          return (uint) (int) obj;
      }
      catch (Exception ex)
      {
      }
      return defaultValue;
    }

    protected static string CleanProcessorNameString(string s)
    {
      if (s == null)
        return (string) null;
      StringBuilder stringBuilder = new StringBuilder();
      for (int index = 0; index < s.Length; ++index)
      {
        char ch = s[index];
        if (ch >= '!' && ch <= '~')
          stringBuilder.Append(ch);
        else if ((ch == ' ' || ch == '\t' || (ch == '\r' || ch == '\n')) && (stringBuilder.Length > 0 && stringBuilder[stringBuilder.Length - 1] != ' '))
          stringBuilder.Append(' ');
      }
      stringBuilder.Replace("(TM)", "");
      stringBuilder.Replace("(tm)", "");
      stringBuilder.Replace("(R)", "");
      stringBuilder.Replace("(r)", "");
      stringBuilder.Replace(" CPU ", " ");
      return stringBuilder.ToString().Trim();
    }

    public float GetScore()
    {
      return this.Score;
    }

    public float EvaluateNumberOfCores()
    {
      float num = 1f;
      switch (this.NumLogicalProcessors)
      {
        case 0:
        case 1:
          num *= 0.1f;
          break;
        case 2:
          num *= 0.2f;
          break;
        case 3:
          num *= 0.4f;
          break;
        case 5:
          num *= 1.1f;
          break;
        case 6:
          num *= 1.3f;
          break;
        case 7:
          num *= 1.4f;
          break;
      }
      if (this.NumLogicalProcessors >= 8U)
        num *= 1.5f;
      if (this.NumPhysicalCores > 1U && this.NumLogicalProcessors > this.NumPhysicalCores)
      {
        if (this.IsAMD && this.NumLogicalProcessors < 8U)
          num *= 0.9f;
        else if (this.NumLogicalProcessors <= 4U)
          num *= 0.8f;
        else if (this.NumLogicalProcessors < 8U)
          num *= 0.85f;
      }
      return num;
    }

    private float Clamp(float x, float lower, float upper)
    {
      return Math.Max(Math.Min(x, upper), lower);
    }

    private void SetScoreRange(uint lowMHZ, float lowScore, uint highMHZ, float highScore)
    {
      this.ScoreTemp_LowScore = lowScore;
      this.ScoreTemp_HighScore = highScore;
      this.ScoreTemp_LowMHZ = (float) lowMHZ;
      this.ScoreTemp_HighMHZ = (float) highMHZ;
    }

    public float ComputeScore()
    {
      string str = this.ProcessorNameString != null ? this.ProcessorNameString : "";
      this.SetScoreRange(1600U, 0.0f, 4000U, 1f);
      if (this.IsIntel)
      {
        this.SetScoreRange(1600U, 0.0f, 4000U, 4f);
        if (str.Contains(" Xeon "))
          this.SetScoreRange(2200U, 2.8f, 3200U, 6f);
        else if (str.Contains(" Core i7-"))
          this.SetScoreRange(2200U, 4.2f, 3600U, 7f);
        else if (str.Contains(" Core i7 "))
          this.SetScoreRange(1700U, 1.9f, 3600U, 4.5f);
        else if (str.Contains(" Core i5-"))
        {
          this.SetScoreRange(1800U, 3f, 3600U, 7f);
          if (str.Contains("U @"))
            this.SetScoreRange(1600U, 3.5f, 3000U, 7f);
        }
        else if (str.Contains(" Core i5 "))
          this.SetScoreRange(2000U, 1.8f, 3100U, 4f);
        else if (str.Contains(" Core i3-"))
          this.SetScoreRange(1800U, 3f, 3600U, 6.5f);
        else if (str.Contains(" Core i3 "))
          this.SetScoreRange(1700U, 1.8f, 3600U, 4f);
        else if (str.Contains(" Core M-5Y"))
          this.SetScoreRange(900U, 1.8f, 1500U, 5.5f);
        else if (str.Contains(" Core2 Extreme ") || str.Contains(" Core2 Quad "))
          this.SetScoreRange(2000U, 2.1f, 3800U, 5.5f);
      }
      else if (this.IsAMD)
      {
        this.SetScoreRange(1900U, 0.0f, 4400U, 4f);
        if (str.Contains("AMD FX-") || str.Contains("AMD FX ") || str.Contains("AMD RX-"))
          this.SetScoreRange(2500U, 3.2f, 4500U, 6f);
        else if (str.Contains("AMD A10-") || str.Contains("AMD A10 "))
          this.SetScoreRange(2200U, 3f, 3800U, 7f);
        else if (str.Contains("AMD A8-") || str.Contains("AMD A8 "))
          this.SetScoreRange(2200U, 2.8f, 3800U, 6.6f);
        else if (str.Contains("AMD A6-") || str.Contains("AMD A6 "))
          this.SetScoreRange(2200U, 2.5f, 3800U, 5f);
        else if (str.Contains("AMD A4-") || str.Contains("AMD A4 "))
          this.SetScoreRange(2200U, 2.8f, 3800U, 6.6f);
        else if (str.Contains("Opteron "))
          this.SetScoreRange(2200U, 2.7f, 3800U, 6f);
        else if (str.Contains("Phenom II "))
          this.SetScoreRange(2300U, 2.2f, 4100U, 5.6f);
        else if (str.Contains("Phenom "))
          this.SetScoreRange(2200U, 2.2f, 3900U, 6f);
        else if (str.Contains("Athlon II "))
          this.SetScoreRange(2200U, 2f, 3600U, 4.7f);
        else if (str.Contains("Athlon "))
          this.SetScoreRange(2400U, 2f, 3800U, 5.6f);
      }
      float num1 = 0.5f;
      if (this.ProcessorMHZ != 0U && (double) this.ScoreTemp_HighMHZ > (double) this.ScoreTemp_LowMHZ)
      {
        num1 = (float) (((double) this.ProcessorMHZ - (double) this.ScoreTemp_LowMHZ) / ((double) this.ScoreTemp_HighMHZ - (double) this.ScoreTemp_LowMHZ));
        if ((double) num1 < 0.0)
          num1 = (float) (((double) num1 - 0.0) * 0.5 + 0.0);
        if ((double) num1 > 1.0)
          num1 = (float) (((double) num1 - 1.0) * 0.699999988079071 + 1.0);
      }
      double num2 = (double) this.ScoreTemp_LowScore * (1.0 - (double) num1) + (double) this.ScoreTemp_HighScore * (double) num1;
      float numberOfCores = this.EvaluateNumberOfCores();
      double num3 = (double) numberOfCores;
      float val1 = (float) (num2 * num3);
      this.ScoreDebugString = string.Format("\"lerp({0:0.0}, {1:0.0}, {2:0.0000}) * {3:0.000} = {4:0.0000}\"", (object) this.ScoreTemp_LowScore, (object) this.ScoreTemp_HighScore, (object) num1, (object) numberOfCores, (object) val1);
      this.Debug_lowScore = this.ScoreTemp_LowScore;
      this.Debug_highScore = this.ScoreTemp_HighScore;
      this.Debug_processorMhz = (float) this.ProcessorMHZ;
      this.Debug_mhzInterpolator = num1;
      this.Debug_coresScaleFactor = numberOfCores;
      return Math.Max(val1, 0.0f);
    }

    public bool IsWeakCPU()
    {
      return (double) this.Score < 3.40000009536743;
    }

    public DetectWeakCPU()
    {
      using (ProcessorsInfo processorsInfo = new ProcessorsInfo())
      {
        this.NumLogicalProcessors = processorsInfo.GetNumLogicalProcessors();
        this.NumPhysicalCores = processorsInfo.GetNumProcessorCores();
      }
      this.ProcessorNameString = DetectWeakCPU.ReadStringRegistryKey("HKEY_LOCAL_MACHINE\\HARDWARE\\DESCRIPTION\\System\\CentralProcessor\\0", nameof (ProcessorNameString), (string) null);
      this.VendorIdentifier = DetectWeakCPU.ReadStringRegistryKey("HKEY_LOCAL_MACHINE\\HARDWARE\\DESCRIPTION\\System\\CentralProcessor\\0", nameof (VendorIdentifier), (string) null);
      this.ProcessorMHZ = DetectWeakCPU.ReadDwordRegistryKey("HKEY_LOCAL_MACHINE\\HARDWARE\\DESCRIPTION\\System\\CentralProcessor\\0", "~MHz", 0U);
      this.ProcessorNameString = DetectWeakCPU.CleanProcessorNameString(this.ProcessorNameString);
      if (this.VendorIdentifier != null)
      {
        this.IsIntel = this.VendorIdentifier.Equals("GenuineIntel");
        this.IsAMD = this.VendorIdentifier.Equals("AuthenticAMD");
      }
      else if (this.ProcessorNameString != null)
      {
        this.IsIntel = this.ProcessorNameString.StartsWith("Intel ");
        this.IsAMD = this.ProcessorNameString.StartsWith("AMD ");
      }
      if (this.ProcessorMHZ < 100U || this.ProcessorMHZ > 20000U)
        this.ProcessorMHZ = 0U;
      this.Score = this.ComputeScore();
    }
  }
}
