﻿
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Printing;
using System.Globalization;
using System.IO;
using System.Reflection;
using System.Resources;
using System.Text;
using System.Threading;
using System.Windows.Forms;

namespace fifasetup_csharp
{
  public class GameSettingsForm : Form
  {
    private FifaAppAlreadyRunningDialogue fifaAppAlreadyRunningDialogue;
    private readonly Resolution resolutionMin16x9;
    private ResourceManager m_ResourceManager;
    private IContainer components;
    private Button OkButton1;
    private Button CancelButton1;
    private System.Windows.Forms.Timer timer1;
    private TabPage VoiceChatTab;
    private GroupBox VoiceChatGroupBoxTEST;
    private Button SoundProperties;
    private CheckBox VoiceChatCheckBox;
    private TabPage DisplayConfigurationTab;
    private GroupBox groupBox1;
    private Label label1;
    private RadioButton MSAA4RadioButton;
    private RadioButton MSAA2RadioButton;
    private RadioButton MSAAOffRadioButton;
    private GroupBox RenderingQualityGroupBox;
    private Label RenderingQualityDescriptionLabel;
    private RadioButton RenderingQualityLowRadioButton;
    private RadioButton RenderingQualityAutoRadioButton;
    private GroupBox ResolutionGroupBox;
    private Label AspectRatioDesc;
    private ComboBox resolutionComboBox1;
    private TabControl TabControl;
    private TabPage ButtonIconsTab;
    private Label ButtonIconTypeLabel;
    private GroupBox ButtonIconTypeGroupBox;
    private RadioButton ControllerOther;
    private RadioButton ControllerXenon;
    private PictureBox ControllerPictureBox;
    private Button buttonResetDefualt;
    private RadioButton viewMode_FullScreen;
    private RadioButton viewMode_Windowed;
    private RadioButton LockGameTo60fpsRadioButton;
    private RadioButton LockGameTo30fpsRadioButton;
    private RadioButton LockGameNoLimitRadioButton;
    private Label LockGameDesc;
    private GroupBox LockGameGroupBox;
    private GroupBox MixModeGroupBox;
    private RadioButton mixmodebutton2;
    private RadioButton mixmodebutton1;
    private RadioButton mixmodebutton0;
    private RadioButton MSAAAutoRadioButton;
    private RadioButton RenderingQualityUltraRadioButton;
    private RadioButton RenderingQualityHighRadioButton;
    private RadioButton RenderingQualityMediumRadioButton;
    private GroupBox DirectX12GroupBox;
    private RadioButton DirectX12RadioButton;
    private RadioButton DirectXAutoRadioButton;
    private RadioButton DirectX11RadioButton;
    private RadioButton viewMode_WindowedBorderless;

    private void GameSettingsForm_Shutdown()
    {
      this.timer1.Enabled = false;
      ((StartingForm) this.Owner).SetSettingsEnabled(true);
    }

    public static string GetSpecialFolderPath()
    {
      return Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.Personal), Settings.GetConfigValue<string>("SETTING_FOLDER", "FIFA 19"));
    }

    private string GetAspectRatioDesc(Resolution resolution)
    {
      return this.m_ResourceManager.GetString("AspectRatioLabelString") + " " + Settings.GetAspectRatioStr(resolution);
    }

    private void LoadDefaultFifaSettingIni(bool bResetToDefault)
    {
      bool flag = Settings.LoadIniFile(Path.Combine(GameSettingsForm.GetSpecialFolderPath(), "fifasetup.ini"));
      this.resolutionComboBox1.Items.Clear();
      this.resolutionComboBox1.SelectionChangeCommitted += new EventHandler(this.resolutionComboBox1_SelectionChangeCommitted);
      List<Resolution> resolutionsForAdapter = Settings.GetResolutionsForAdapter();
      foreach (object obj in resolutionsForAdapter)
        this.resolutionComboBox1.Items.Add(obj);
      if (!flag | bResetToDefault)
      {
        Settings.CreateSettingsForAdapter();
      }
      else
      {
        this.UpdateControllerDefault();
        this.UpdateVoiceChat();
        this.UpdateMixMode();
        this.UpdateDirectX();
      }
      this.ValidateCurrentResolution(resolutionsForAdapter);
      this.AspectRatioDesc.Text = this.GetAspectRatioDesc(this.resolutionComboBox1.SelectedItem as Resolution);
      this.UpdateViewMode();
      this.UpdateRenderQualitySettings();
      this.UpdateMSAAValue();
      this.UpdateLockGame();
      this.AutoSelectScreenRatio();
    }

    private void ValidateCurrentResolution(List<Resolution> resolutions)
    {
      if (resolutions.Count == 0)
      {
        this.resolutionComboBox1.Items.Add((object) this.resolutionMin16x9);
        this.viewMode_Windowed.Checked = true;
        this.viewMode_FullScreen.Checked = false;
        this.viewMode_FullScreen.Enabled = false;
      }
      Resolution resolution = new Resolution();
      resolution.w = Settings.GetValue<int>("RESOLUTIONWIDTH", this.resolutionMin16x9.w);
      resolution.h = Settings.GetValue<int>("RESOLUTIONHEIGHT", this.resolutionMin16x9.h);
      if (!resolutions.Contains(resolution))
      {
        resolution = this.resolutionComboBox1.Items[0] as Resolution;
        if (resolution != null)
        {
          Settings.SetValue<int>("RESOLUTIONWIDTH", resolution.w);
          Settings.SetValue<int>("RESOLUTIONHEIGHT", resolution.h);
        }
      }
      this.resolutionComboBox1.Text = resolution.ToString();
    }

    private void UpdateViewMode()
    {
      int num1 = Settings.GetValue<int>("FULLSCREEN", 1);
      int num2 = Settings.GetValue<int>("WINDOWED_BORDERLESS", 0);
      if (num1 == 0)
      {
        this.viewMode_FullScreen.Checked = false;
        this.viewMode_Windowed.Checked = num2 == 0;
        this.viewMode_WindowedBorderless.Checked = num2 == 1;
      }
      else
      {
        if (num1 != 1)
          return;
        this.viewMode_FullScreen.Checked = true;
        this.viewMode_Windowed.Checked = false;
        this.viewMode_WindowedBorderless.Checked = false;
      }
    }

    private void UpdateControllerDefault()
    {
      switch (Settings.GetValue<int>("CONTROLLER_DEFAULT", 0))
      {
        case 0:
          this.ControllerOther.Checked = false;
          this.ControllerXenon.Checked = true;
          break;
        case 1:
          this.ControllerOther.Checked = true;
          this.ControllerXenon.Checked = false;
          break;
      }
    }

    private void UpdateRenderQualitySettings()
    {
      eRenderingQualityLevel renderingQualityLevel = (eRenderingQualityLevel) Settings.GetValue<int>("RENDERINGQUALITY", 0);
      this.RenderingQualityAutoRadioButton.Checked = false;
      this.RenderingQualityLowRadioButton.Checked = false;
      this.RenderingQualityMediumRadioButton.Checked = false;
      this.RenderingQualityHighRadioButton.Checked = false;
      this.RenderingQualityUltraRadioButton.Checked = false;
      switch (renderingQualityLevel)
      {
        case eRenderingQualityLevel.RENDERQUALITY_AUTO:
          this.RenderingQualityAutoRadioButton.Checked = true;
          break;
        case eRenderingQualityLevel.RENDERQUALITY_LOW:
          this.RenderingQualityLowRadioButton.Checked = true;
          break;
        case eRenderingQualityLevel.RENDERQUALITY_MEDIUM:
          this.RenderingQualityMediumRadioButton.Checked = true;
          break;
        case eRenderingQualityLevel.RENDERQUALITY_HIGH:
          this.RenderingQualityHighRadioButton.Checked = true;
          break;
        case eRenderingQualityLevel.RENDERQUALITY_ULTRA:
          this.RenderingQualityUltraRadioButton.Checked = true;
          break;
      }
    }

    private void UpdateLockGame()
    {
      GameSettingsForm.eVSyncRate eVsyncRate = (GameSettingsForm.eVSyncRate) Settings.GetValue<int>("WAITFORVSYNC", 0);
      this.LockGameNoLimitRadioButton.Checked = false;
      this.LockGameTo30fpsRadioButton.Checked = false;
      this.LockGameTo60fpsRadioButton.Checked = false;
      switch (eVsyncRate)
      {
        case GameSettingsForm.eVSyncRate.VSYNC_DISABLED:
          this.LockGameNoLimitRadioButton.Checked = true;
          break;
        case GameSettingsForm.eVSyncRate.VSYNC_60HZ:
          this.LockGameTo60fpsRadioButton.Checked = true;
          break;
        case GameSettingsForm.eVSyncRate.VSYNC_30HZ:
          this.LockGameTo30fpsRadioButton.Checked = true;
          break;
      }
    }

    private void UpdateMSAAValue()
    {
      GameSettingsForm.eMSAA eMsaa = (GameSettingsForm.eMSAA) Settings.GetValue<int>("MSAA_LEVEL", 1);
      this.MSAAAutoRadioButton.Checked = false;
      this.MSAAOffRadioButton.Checked = false;
      this.MSAA2RadioButton.Checked = false;
      this.MSAA4RadioButton.Checked = false;
      switch (eMsaa)
      {
        case GameSettingsForm.eMSAA.MSAA_AUTO:
          this.MSAAAutoRadioButton.Checked = true;
          break;
        case GameSettingsForm.eMSAA.MSAA_OFF:
          this.MSAAOffRadioButton.Checked = true;
          break;
        case GameSettingsForm.eMSAA.MSAA_TWOPASS:
          this.MSAA2RadioButton.Checked = true;
          break;
        case GameSettingsForm.eMSAA.MSAA_FOURPASS:
          this.MSAA4RadioButton.Checked = true;
          break;
      }
    }

    private void UpdateVoiceChat()
    {
      this.VoiceChatCheckBox.Checked = false;
      this.VoiceChatCheckBox.Enabled = true;
      if (Settings.GetValue<int>("VOICECHAT", 1) != 0)
        this.VoiceChatCheckBox.Checked = true;
      if (Settings.GetConfigValue<int>("DEMO", 0) == 0)
        return;
      this.VoiceChatCheckBox.Checked = false;
      this.VoiceChatCheckBox.Enabled = false;
    }

    private void UpdateMixMode()
    {
      GameSettingsForm.eMixMode eMixMode = (GameSettingsForm.eMixMode) Settings.GetValue<int>("AUDIO_MIX_MODE", 0);
      this.mixmodebutton0.Checked = false;
      this.mixmodebutton1.Checked = false;
      this.mixmodebutton2.Checked = false;
      switch (eMixMode)
      {
        case GameSettingsForm.eMixMode.MIXMODE_STEREO:
          this.mixmodebutton0.Checked = true;
          break;
        case GameSettingsForm.eMixMode.MIXMODE_5_1:
          this.mixmodebutton1.Checked = true;
          break;
        case GameSettingsForm.eMixMode.MIXMODE_7_1:
          this.mixmodebutton2.Checked = true;
          break;
      }
    }

    private void UpdateDirectX()
    {
      GameSettingsForm.eDirectxMode eDirectxMode = (GameSettingsForm.eDirectxMode) Settings.GetValue<int>("DIRECTX_SELECT", 1);
      this.DirectX11RadioButton.Checked = false;
      this.DirectX12RadioButton.Checked = false;
      this.DirectXAutoRadioButton.Checked = false;
      switch (eDirectxMode)
      {
        case GameSettingsForm.eDirectxMode.DXSELECT_AUTO:
          this.DirectXAutoRadioButton.Checked = true;
          break;
        case GameSettingsForm.eDirectxMode.DXSELECT_11:
          this.DirectX11RadioButton.Checked = true;
          break;
        case GameSettingsForm.eDirectxMode.DXSELECT_12:
          this.DirectX12RadioButton.Checked = true;
          break;
      }
    }

    public void SetCultureInfo(CultureInfo cultureInfo)
    {
      Thread.CurrentThread.CurrentUICulture = cultureInfo;
      this.SwitchLocal();
    }

    private void SwitchLocal()
    {
      this.Text = this.m_ResourceManager.GetString("GameSettingsWindowTitle");
      this.DisplayConfigurationTab.Text = this.m_ResourceManager.GetString("DisplayConfigurationTabString");
      this.ResolutionGroupBox.Text = this.m_ResourceManager.GetString("ResolutionGroupBoxString");
      this.RenderingQualityGroupBox.Text = this.m_ResourceManager.GetString("RenderingQualityGroupBoxString");
      this.RenderingQualityAutoRadioButton.Text = this.m_ResourceManager.GetString("RenderingQualityAutoRadioButtonString");
      this.RenderingQualityLowRadioButton.Text = this.m_ResourceManager.GetString("RenderingQualityLowRadioButtonString");
      this.RenderingQualityMediumRadioButton.Text = this.m_ResourceManager.GetString("RenderingQualityMediumRadioButtonString");
      this.RenderingQualityHighRadioButton.Text = this.m_ResourceManager.GetString("RenderingQualityHighRadioButtonString");
      this.RenderingQualityUltraRadioButton.Text = this.m_ResourceManager.GetString("RenderingQualityUltraRadioButtonString");
      this.ButtonIconsTab.Text = this.m_ResourceManager.GetString("ButtonIconsTabString");
      this.ButtonIconTypeGroupBox.Text = this.m_ResourceManager.GetString("ButtonIconTypeGroupBoxString");
      this.ButtonIconTypeLabel.Text = this.m_ResourceManager.GetString("ButtonIconTypeLabelString");
      this.ControllerXenon.Text = this.m_ResourceManager.GetString("ControllerXenonString");
      this.ControllerOther.Text = this.m_ResourceManager.GetString("ControllerOtherString");
      this.VoiceChatTab.Text = this.m_ResourceManager.GetString("VoiceChatTabString");
      this.VoiceChatCheckBox.Text = this.m_ResourceManager.GetString("VoiceChatCheckBoxString");
      this.SoundProperties.Text = this.m_ResourceManager.GetString("SoundPropertiesString");
      this.OkButton1.Text = this.m_ResourceManager.GetString("OkayButton");
      this.CancelButton1.Text = this.m_ResourceManager.GetString("Cancel");
      this.buttonResetDefualt.Text = this.m_ResourceManager.GetString("RestoreDefault");
      this.viewMode_FullScreen.Text = this.m_ResourceManager.GetString("VIEWMODE_FULLSCREEN");
      this.viewMode_Windowed.Text = this.m_ResourceManager.GetString("VIEWMODE_WINDOWED");
      this.viewMode_WindowedBorderless.Text = this.m_ResourceManager.GetString("WindowedBorderlessString");
      this.viewMode_FullScreen.Visible = true;
      this.viewMode_Windowed.Visible = true;
      this.viewMode_WindowedBorderless.Visible = true;
      this.LockGameGroupBox.Text = this.m_ResourceManager.GetString("LockGameGroupBoxString");
      this.LockGameNoLimitRadioButton.Text = this.m_ResourceManager.GetString("LockGameNoLimitRadioButton");
      this.LockGameTo30fpsRadioButton.Text = this.m_ResourceManager.GetString("LockGameTo30fpsRadioButton");
      this.LockGameTo60fpsRadioButton.Text = this.m_ResourceManager.GetString("LockGameTo60fpsRadioButton");
      this.RenderingQualityDescriptionLabel.Text = this.m_ResourceManager.GetString("RenderingQualityAutoDescription");
      if (this.RenderingQualityAutoRadioButton.Checked)
        this.RenderingQualityDescriptionLabel.Text = this.m_ResourceManager.GetString("RenderingQualityAutoDescription");
      else if (this.RenderingQualityLowRadioButton.Checked)
        this.RenderingQualityDescriptionLabel.Text = this.m_ResourceManager.GetString("RenderingQualityLowDescription");
      else if (this.RenderingQualityMediumRadioButton.Checked)
        this.RenderingQualityDescriptionLabel.Text = this.m_ResourceManager.GetString("RenderingQualityMediumDescription");
      else if (this.RenderingQualityHighRadioButton.Checked)
        this.RenderingQualityDescriptionLabel.Text = this.m_ResourceManager.GetString("RenderingQualityHighDescription");
      else if (this.RenderingQualityUltraRadioButton.Checked)
        this.RenderingQualityDescriptionLabel.Text = this.m_ResourceManager.GetString("RenderingQualityUltraDescription");
      this.LockGameDesc.Text = this.m_ResourceManager.GetString("LockGameNoLimitDesc");
      if (this.LockGameNoLimitRadioButton.Checked)
        this.LockGameDesc.Text = this.m_ResourceManager.GetString("LockGameNoLimitDesc");
      if (this.LockGameTo30fpsRadioButton.Checked)
        this.LockGameDesc.Text = this.m_ResourceManager.GetString("LockGameTo30fpsDesc");
      if (this.LockGameTo60fpsRadioButton.Checked)
        this.LockGameDesc.Text = this.m_ResourceManager.GetString("LockGameTo60fpsDesc");
      if (this.fifaAppAlreadyRunningDialogue != null)
        this.fifaAppAlreadyRunningDialogue.SwitchLocal();
      this.groupBox1.Text = this.m_ResourceManager.GetString("MSAAOptions");
      this.MSAAOffRadioButton.Text = this.m_ResourceManager.GetString("Off");
      this.MSAAAutoRadioButton.Text = this.m_ResourceManager.GetString("MSAAAuto");
      this.label1.Text = this.m_ResourceManager.GetString("MSAADesc");
      this.VoiceChatGroupBoxTEST.Text = this.m_ResourceManager.GetString("VoiceChatCheckBoxString");
      this.MixModeGroupBox.Text = this.m_ResourceManager.GetString("MixModeGroupBox");
      this.mixmodebutton2.Text = this.m_ResourceManager.GetString("MixModeButton2");
      this.mixmodebutton1.Text = this.m_ResourceManager.GetString("MixModeButton1");
      this.mixmodebutton0.Text = this.m_ResourceManager.GetString("MixModeButton0");
      this.DirectX12GroupBox.Text = this.m_ResourceManager.GetString("RenderingDirectXSelectBoxString");
      this.DirectXAutoRadioButton.Text = this.m_ResourceManager.GetString("RenderingDirectXSelectAuto");
      this.DirectX11RadioButton.Text = this.m_ResourceManager.GetString("RenderingDirectXSelect11");
      this.DirectX12RadioButton.Text = this.m_ResourceManager.GetString("RenderingDirectXSelect12");
    }

    public GameSettingsForm(RightToLeft rtl)
    {
      this.m_ResourceManager = new ResourceManager("fifasetup_csharp.Resources.StringResource", Assembly.GetExecutingAssembly());
      this.fifaAppAlreadyRunningDialogue = new FifaAppAlreadyRunningDialogue(rtl);
      this.resolutionMin16x9 = new Resolution(1280, 720);
      this.InitializeComponent();
      this.RightToLeft = rtl;
      this.CheckForLowResolution();
      Settings.CreateVideoDictionary();
      string str = "resources\\Controllers.PNG";
      if (File.Exists(str))
        this.ControllerPictureBox.Image = Image.FromFile(str);
      this.SwitchLocal();
      this.LoadDefaultFifaSettingIni(false);
      this.timer1.Enabled = true;
    }

    private void CheckForLowResolution()
    {
      Rectangle rectangle1 = this.Bounds;
      int width1 = rectangle1.Width;
      rectangle1 = Screen.PrimaryScreen.WorkingArea;
      int width2 = rectangle1.Width;
      if (width1 <= width2)
      {
        Rectangle rectangle2 = this.Bounds;
        int height1 = rectangle2.Height;
        rectangle2 = Screen.PrimaryScreen.WorkingArea;
        int height2 = rectangle2.Height;
        if (height1 <= height2)
          return;
      }
      this.AutoScroll = true;
      this.SetAutoScrollMargin(5, 5);
      this.AutoScrollMinSize = new Size(5, 5);
      this.MaximizedBounds = Screen.PrimaryScreen.WorkingArea;
      this.WindowState = FormWindowState.Maximized;
    }

    private void SaveFifaSettingIni()
    {
      Resolution selectedItem = (Resolution) this.resolutionComboBox1.SelectedItem;
      if (selectedItem != null)
      {
        Settings.SetValue<int>("RESOLUTIONWIDTH", selectedItem.w);
        Settings.SetValue<int>("RESOLUTIONHEIGHT", selectedItem.h);
      }
      if (this.viewMode_FullScreen.Checked)
      {
        Settings.SetValue<int>("FULLSCREEN", 1);
        Settings.SetValue<int>("WINDOWED_BORDERLESS", 0);
      }
      else
      {
        Settings.SetValue<int>("FULLSCREEN", 0);
        Settings.SetValue<int>("WINDOWED_BORDERLESS", this.viewMode_WindowedBorderless.Checked ? 1 : 0);
      }
      if (this.ControllerXenon.Checked)
        Settings.SetValue<int>("CONTROLLER_DEFAULT", 0);
      else if (this.ControllerOther.Checked)
        Settings.SetValue<int>("CONTROLLER_DEFAULT", 1);
      if (this.RenderingQualityAutoRadioButton.Checked)
        Settings.SetValue<int>("RENDERINGQUALITY", 0);
      else if (this.RenderingQualityLowRadioButton.Checked)
        Settings.SetValue<int>("RENDERINGQUALITY", 1);
      else if (this.RenderingQualityMediumRadioButton.Checked)
        Settings.SetValue<int>("RENDERINGQUALITY", 2);
      else if (this.RenderingQualityHighRadioButton.Checked)
        Settings.SetValue<int>("RENDERINGQUALITY", 3);
      else if (this.RenderingQualityUltraRadioButton.Checked)
        Settings.SetValue<int>("RENDERINGQUALITY", 4);
      if (this.MSAAAutoRadioButton.Checked)
        Settings.SetValue<int>("MSAA_LEVEL", 0);
      else if (this.MSAAOffRadioButton.Checked)
        Settings.SetValue<int>("MSAA_LEVEL", 1);
      else if (this.MSAA2RadioButton.Checked)
        Settings.SetValue<int>("MSAA_LEVEL", 2);
      else if (this.MSAA4RadioButton.Checked)
        Settings.SetValue<int>("MSAA_LEVEL", 3);
      if (this.LockGameNoLimitRadioButton.Checked)
        Settings.SetValue<int>("WAITFORVSYNC", 0);
      else if (this.LockGameTo30fpsRadioButton.Checked)
        Settings.SetValue<int>("WAITFORVSYNC", 2);
      else if (this.LockGameTo60fpsRadioButton.Checked)
        Settings.SetValue<int>("WAITFORVSYNC", 1);
      if (this.VoiceChatCheckBox.Checked)
        Settings.SetValue<int>("VOICECHAT", 1);
      else
        Settings.SetValue<int>("VOICECHAT", 0);
      if (this.mixmodebutton0.Checked)
        Settings.SetValue<int>("AUDIO_MIX_MODE", 0);
      else if (this.mixmodebutton1.Checked)
        Settings.SetValue<int>("AUDIO_MIX_MODE", 1);
      else if (this.mixmodebutton2.Checked)
        Settings.SetValue<int>("AUDIO_MIX_MODE", 2);
      if (this.DirectXAutoRadioButton.Checked)
        Settings.SetValue<int>("DIRECTX_SELECT", 0);
      else if (this.DirectX11RadioButton.Checked)
        Settings.SetValue<int>("DIRECTX_SELECT", 1);
      else if (this.DirectX12RadioButton.Checked)
        Settings.SetValue<int>("DIRECTX_SELECT", 2);
      string specialFolderPath = GameSettingsForm.GetSpecialFolderPath();
      string filename = Path.Combine(specialFolderPath, "fifasetup.ini");
      if (!Directory.Exists(specialFolderPath))
        Directory.CreateDirectory(specialFolderPath);
      Settings.SaveIniFile(filename);
    }

    private void OkButton_Click(object sender, EventArgs e)
    {
      this.SaveFifaSettingIni();
      if (StartingForm.IsAppAlreadyRunning(Settings.GetLaunchProcessName()))
      {
        this.Enabled = false;
        this.fifaAppAlreadyRunningDialogue.Show((IWin32Window) this);
      }
      else
        this.CloseAndFree();
    }

    private void SelectedTabChange(object sender, EventArgs e)
    {
      this.SaveFifaSettingIni();
    }

    private void SoundProperties_Click(object sender, EventArgs e)
    {
      Process.Start("control.exe", "mmsys.cpl,,2");
    }

    private void CloseAndFree()
    {
      ((StartingForm) this.Owner).SetSettingsEnabled(true);
      this.Dispose();
    }

    private void CancelButton1_Click(object sender, EventArgs e)
    {
      this.CloseAndFree();
    }

    private void RenderingQualitySuperLowRadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void RenderingQualityLowRadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void RenderingQualityMediumRadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void RenderingQualityHighRadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void radioWindowButton0_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void radioWindowButton1_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void VoiceChatCheckBox_CheckedChanged(object sender, EventArgs e)
    {
    }

    private void resolutionComboBox1_SelectionChangeCommitted(object sender, EventArgs e)
    {
      this.AutoSelectScreenRatio();
    }

    private void AutoSelectScreenRatio()
    {
      Resolution selectedItem = (Resolution) this.resolutionComboBox1.SelectedItem;
      if (selectedItem == null)
        return;
      double num1 = (16.0 / 9.0 - 4.0 / 3.0) / 2.0;
      double num2 = (double) selectedItem.w / (double) selectedItem.h;
      this.AspectRatioDesc.Text = this.GetAspectRatioDesc(selectedItem);
    }

    private void FlowLayoutPanel_MouseEnter(object sender, EventArgs e)
    {
      ((Control) sender).Focus();
    }

    private void TableLayoutPanel_MouseEnter(object sender, EventArgs e)
    {
      ((Control) sender).Focus();
    }

    private void PrintButton1_Click(object sender, EventArgs e)
    {
      PrintDocument printDocument = new PrintDocument();
      printDocument.PrintPage += new PrintPageEventHandler(this.PrintImage);
      printDocument.DefaultPageSettings.Landscape = true;
      printDocument.Print();
    }

    private void PrintImage(object o, PrintPageEventArgs e)
    {
      int width = this.Width;
      int height = this.Height;
      Rectangle targetBounds = new Rectangle(0, 0, width, height);
      Bitmap bitmap = new Bitmap(width, height);
      this.DrawToBitmap(bitmap, targetBounds);
      Point point = new Point(10, 10);
      e.Graphics.DrawImage((Image) bitmap, point);
    }

    private void LockGameNoLimit_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void LockGameTo30fps_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void LockGameTo60fps_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void DefaultBtn_ResetToDefault(object sender, EventArgs e)
    {
      this.LoadDefaultFifaSettingIni(true);
    }

    private void DisableWindowsAero_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void GameSettingsForm_Load(object sender, EventArgs e)
    {
    }

    private void MSAAAutoRadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void RenderingQualityMediumRadioButton_CheckedChanged_1(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void RenderingQualityHighRadioButton_CheckedChanged_1(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void RenderingQualityUltraRadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void viewMode_Windowed_CheckedChanged(object sender, EventArgs e)
    {
    }

    private void viewMode_FullScreen_CheckedChanged(object sender, EventArgs e)
    {
    }

    private void resolutionComboBox1_SelectedIndexChanged(object sender, EventArgs e)
    {
    }

    private void DirectXAutoRadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void DirectX11RadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void DirectX12RadioButton_CheckedChanged(object sender, EventArgs e)
    {
      this.SwitchLocal();
    }

    private void viewMode_WindowedBorderless_CheckedChanged(object sender, EventArgs e)
    {
    }

    protected override void Dispose(bool disposing)
    {
      this.GameSettingsForm_Shutdown();
      if (disposing && this.components != null)
        this.components.Dispose();
      base.Dispose(disposing);
    }

    private void InitializeComponent()
    {
      this.components = (IContainer) new Container();
      ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof (GameSettingsForm));
      this.OkButton1 = new Button();
      this.CancelButton1 = new Button();
      this.timer1 = new System.Windows.Forms.Timer(this.components);
      this.VoiceChatTab = new TabPage();
      this.MixModeGroupBox = new GroupBox();
      this.mixmodebutton2 = new RadioButton();
      this.mixmodebutton1 = new RadioButton();
      this.mixmodebutton0 = new RadioButton();
      this.VoiceChatGroupBoxTEST = new GroupBox();
      this.SoundProperties = new Button();
      this.VoiceChatCheckBox = new CheckBox();
      this.DisplayConfigurationTab = new TabPage();
      this.DirectX12GroupBox = new GroupBox();
      this.DirectX12RadioButton = new RadioButton();
      this.DirectXAutoRadioButton = new RadioButton();
      this.DirectX11RadioButton = new RadioButton();
      this.buttonResetDefualt = new Button();
      this.groupBox1 = new GroupBox();
      this.MSAAAutoRadioButton = new RadioButton();
      this.label1 = new Label();
      this.MSAA4RadioButton = new RadioButton();
      this.MSAA2RadioButton = new RadioButton();
      this.MSAAOffRadioButton = new RadioButton();
      this.LockGameGroupBox = new GroupBox();
      this.LockGameDesc = new Label();
      this.LockGameNoLimitRadioButton = new RadioButton();
      this.LockGameTo30fpsRadioButton = new RadioButton();
      this.LockGameTo60fpsRadioButton = new RadioButton();
      this.RenderingQualityGroupBox = new GroupBox();
      this.RenderingQualityUltraRadioButton = new RadioButton();
      this.RenderingQualityHighRadioButton = new RadioButton();
      this.RenderingQualityMediumRadioButton = new RadioButton();
      this.RenderingQualityDescriptionLabel = new Label();
      this.RenderingQualityLowRadioButton = new RadioButton();
      this.RenderingQualityAutoRadioButton = new RadioButton();
      this.ResolutionGroupBox = new GroupBox();
      this.viewMode_WindowedBorderless = new RadioButton();
      this.viewMode_FullScreen = new RadioButton();
      this.viewMode_Windowed = new RadioButton();
      this.AspectRatioDesc = new Label();
      this.resolutionComboBox1 = new ComboBox();
      this.TabControl = new TabControl();
      this.ButtonIconsTab = new TabPage();
      this.ButtonIconTypeGroupBox = new GroupBox();
      this.ControllerPictureBox = new PictureBox();
      this.ControllerOther = new RadioButton();
      this.ControllerXenon = new RadioButton();
      this.ButtonIconTypeLabel = new Label();
      this.VoiceChatTab.SuspendLayout();
      this.MixModeGroupBox.SuspendLayout();
      this.VoiceChatGroupBoxTEST.SuspendLayout();
      this.DisplayConfigurationTab.SuspendLayout();
      this.DirectX12GroupBox.SuspendLayout();
      this.groupBox1.SuspendLayout();
      this.LockGameGroupBox.SuspendLayout();
      this.RenderingQualityGroupBox.SuspendLayout();
      this.ResolutionGroupBox.SuspendLayout();
      this.TabControl.SuspendLayout();
      this.ButtonIconsTab.SuspendLayout();
      this.ButtonIconTypeGroupBox.SuspendLayout();
      ((ISupportInitialize) this.ControllerPictureBox).BeginInit();
      this.SuspendLayout();
      componentResourceManager.ApplyResources((object) this.OkButton1, "OkButton1");
      this.OkButton1.Name = "OkButton1";
      this.OkButton1.UseVisualStyleBackColor = true;
      this.OkButton1.Click += new EventHandler(this.OkButton_Click);
      componentResourceManager.ApplyResources((object) this.CancelButton1, "CancelButton1");
      this.CancelButton1.Name = "CancelButton1";
      this.CancelButton1.UseVisualStyleBackColor = true;
      this.CancelButton1.Click += new EventHandler(this.CancelButton1_Click);
      this.timer1.Interval = 16;
      this.VoiceChatTab.Controls.Add((Control) this.MixModeGroupBox);
      this.VoiceChatTab.Controls.Add((Control) this.VoiceChatGroupBoxTEST);
      componentResourceManager.ApplyResources((object) this.VoiceChatTab, "VoiceChatTab");
      this.VoiceChatTab.Name = "VoiceChatTab";
      this.VoiceChatTab.UseVisualStyleBackColor = true;
      this.MixModeGroupBox.Controls.Add((Control) this.mixmodebutton2);
      this.MixModeGroupBox.Controls.Add((Control) this.mixmodebutton1);
      this.MixModeGroupBox.Controls.Add((Control) this.mixmodebutton0);
      componentResourceManager.ApplyResources((object) this.MixModeGroupBox, "MixModeGroupBox");
      this.MixModeGroupBox.Name = "MixModeGroupBox";
      this.MixModeGroupBox.TabStop = false;
      componentResourceManager.ApplyResources((object) this.mixmodebutton2, "mixmodebutton2");
      this.mixmodebutton2.Name = "mixmodebutton2";
      this.mixmodebutton2.UseVisualStyleBackColor = true;
      componentResourceManager.ApplyResources((object) this.mixmodebutton1, "mixmodebutton1");
      this.mixmodebutton1.Name = "mixmodebutton1";
      this.mixmodebutton1.UseVisualStyleBackColor = true;
      componentResourceManager.ApplyResources((object) this.mixmodebutton0, "mixmodebutton0");
      this.mixmodebutton0.Checked = true;
      this.mixmodebutton0.Name = "mixmodebutton0";
      this.mixmodebutton0.TabStop = true;
      this.mixmodebutton0.UseVisualStyleBackColor = true;
      this.VoiceChatGroupBoxTEST.Controls.Add((Control) this.SoundProperties);
      this.VoiceChatGroupBoxTEST.Controls.Add((Control) this.VoiceChatCheckBox);
      componentResourceManager.ApplyResources((object) this.VoiceChatGroupBoxTEST, "VoiceChatGroupBoxTEST");
      this.VoiceChatGroupBoxTEST.Name = "VoiceChatGroupBoxTEST";
      this.VoiceChatGroupBoxTEST.TabStop = false;
      componentResourceManager.ApplyResources((object) this.SoundProperties, "SoundProperties");
      this.SoundProperties.Name = "SoundProperties";
      this.SoundProperties.UseVisualStyleBackColor = true;
      this.SoundProperties.Click += new EventHandler(this.SoundProperties_Click);
      componentResourceManager.ApplyResources((object) this.VoiceChatCheckBox, "VoiceChatCheckBox");
      this.VoiceChatCheckBox.Name = "VoiceChatCheckBox";
      this.VoiceChatCheckBox.UseVisualStyleBackColor = true;
      this.VoiceChatCheckBox.CheckedChanged += new EventHandler(this.VoiceChatCheckBox_CheckedChanged);
      this.DisplayConfigurationTab.Controls.Add((Control) this.DirectX12GroupBox);
      this.DisplayConfigurationTab.Controls.Add((Control) this.buttonResetDefualt);
      this.DisplayConfigurationTab.Controls.Add((Control) this.groupBox1);
      this.DisplayConfigurationTab.Controls.Add((Control) this.LockGameGroupBox);
      this.DisplayConfigurationTab.Controls.Add((Control) this.RenderingQualityGroupBox);
      this.DisplayConfigurationTab.Controls.Add((Control) this.ResolutionGroupBox);
      componentResourceManager.ApplyResources((object) this.DisplayConfigurationTab, "DisplayConfigurationTab");
      this.DisplayConfigurationTab.Name = "DisplayConfigurationTab";
      this.DisplayConfigurationTab.UseVisualStyleBackColor = true;
      this.DirectX12GroupBox.Controls.Add((Control) this.DirectX12RadioButton);
      this.DirectX12GroupBox.Controls.Add((Control) this.DirectXAutoRadioButton);
      this.DirectX12GroupBox.Controls.Add((Control) this.DirectX11RadioButton);
      componentResourceManager.ApplyResources((object) this.DirectX12GroupBox, "DirectX12GroupBox");
      this.DirectX12GroupBox.Name = "DirectX12GroupBox";
      this.DirectX12GroupBox.TabStop = false;
      componentResourceManager.ApplyResources((object) this.DirectX12RadioButton, "DirectX12RadioButton");
      this.DirectX12RadioButton.Name = "DirectX12RadioButton";
      this.DirectX12RadioButton.UseVisualStyleBackColor = true;
      this.DirectX12RadioButton.CheckedChanged += new EventHandler(this.DirectX12RadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.DirectXAutoRadioButton, "DirectXAutoRadioButton");
      this.DirectXAutoRadioButton.Name = "DirectXAutoRadioButton";
      this.DirectXAutoRadioButton.UseVisualStyleBackColor = true;
      this.DirectXAutoRadioButton.CheckedChanged += new EventHandler(this.DirectXAutoRadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.DirectX11RadioButton, "DirectX11RadioButton");
      this.DirectX11RadioButton.Name = "DirectX11RadioButton";
      this.DirectX11RadioButton.UseVisualStyleBackColor = true;
      this.DirectX11RadioButton.CheckedChanged += new EventHandler(this.DirectX11RadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.buttonResetDefualt, "buttonResetDefualt");
      this.buttonResetDefualt.Name = "buttonResetDefualt";
      this.buttonResetDefualt.UseVisualStyleBackColor = true;
      this.buttonResetDefualt.Click += new EventHandler(this.DefaultBtn_ResetToDefault);
      this.groupBox1.Controls.Add((Control) this.MSAAAutoRadioButton);
      this.groupBox1.Controls.Add((Control) this.label1);
      this.groupBox1.Controls.Add((Control) this.MSAA4RadioButton);
      this.groupBox1.Controls.Add((Control) this.MSAA2RadioButton);
      this.groupBox1.Controls.Add((Control) this.MSAAOffRadioButton);
      componentResourceManager.ApplyResources((object) this.groupBox1, "groupBox1");
      this.groupBox1.Name = "groupBox1";
      this.groupBox1.TabStop = false;
      componentResourceManager.ApplyResources((object) this.MSAAAutoRadioButton, "MSAAAutoRadioButton");
      this.MSAAAutoRadioButton.Checked = true;
      this.MSAAAutoRadioButton.Name = "MSAAAutoRadioButton";
      this.MSAAAutoRadioButton.TabStop = true;
      this.MSAAAutoRadioButton.UseVisualStyleBackColor = true;
      this.MSAAAutoRadioButton.CheckedChanged += new EventHandler(this.MSAAAutoRadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.label1, "label1");
      this.label1.Name = "label1";
      componentResourceManager.ApplyResources((object) this.MSAA4RadioButton, "MSAA4RadioButton");
      this.MSAA4RadioButton.Name = "MSAA4RadioButton";
      this.MSAA4RadioButton.UseVisualStyleBackColor = true;
      this.MSAA4RadioButton.CheckedChanged += new EventHandler(this.RenderingQualityHighRadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.MSAA2RadioButton, "MSAA2RadioButton");
      this.MSAA2RadioButton.Name = "MSAA2RadioButton";
      this.MSAA2RadioButton.UseVisualStyleBackColor = true;
      this.MSAA2RadioButton.CheckedChanged += new EventHandler(this.RenderingQualityMediumRadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.MSAAOffRadioButton, "MSAAOffRadioButton");
      this.MSAAOffRadioButton.Name = "MSAAOffRadioButton";
      this.MSAAOffRadioButton.UseVisualStyleBackColor = true;
      this.MSAAOffRadioButton.CheckedChanged += new EventHandler(this.RenderingQualityLowRadioButton_CheckedChanged);
      this.LockGameGroupBox.Controls.Add((Control) this.LockGameDesc);
      this.LockGameGroupBox.Controls.Add((Control) this.LockGameNoLimitRadioButton);
      this.LockGameGroupBox.Controls.Add((Control) this.LockGameTo30fpsRadioButton);
      this.LockGameGroupBox.Controls.Add((Control) this.LockGameTo60fpsRadioButton);
      componentResourceManager.ApplyResources((object) this.LockGameGroupBox, "LockGameGroupBox");
      this.LockGameGroupBox.Name = "LockGameGroupBox";
      this.LockGameGroupBox.TabStop = false;
      componentResourceManager.ApplyResources((object) this.LockGameDesc, "LockGameDesc");
      this.LockGameDesc.Name = "LockGameDesc";
      componentResourceManager.ApplyResources((object) this.LockGameNoLimitRadioButton, "LockGameNoLimitRadioButton");
      this.LockGameNoLimitRadioButton.Name = "LockGameNoLimitRadioButton";
      this.LockGameNoLimitRadioButton.UseVisualStyleBackColor = true;
      this.LockGameNoLimitRadioButton.CheckedChanged += new EventHandler(this.LockGameNoLimit_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.LockGameTo30fpsRadioButton, "LockGameTo30fpsRadioButton");
      this.LockGameTo30fpsRadioButton.Name = "LockGameTo30fpsRadioButton";
      this.LockGameTo30fpsRadioButton.UseVisualStyleBackColor = true;
      this.LockGameTo30fpsRadioButton.CheckedChanged += new EventHandler(this.LockGameTo30fps_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.LockGameTo60fpsRadioButton, "LockGameTo60fpsRadioButton");
      this.LockGameTo60fpsRadioButton.Name = "LockGameTo60fpsRadioButton";
      this.LockGameTo60fpsRadioButton.UseVisualStyleBackColor = true;
      this.LockGameTo60fpsRadioButton.CheckedChanged += new EventHandler(this.LockGameTo60fps_CheckedChanged);
      this.RenderingQualityGroupBox.Controls.Add((Control) this.RenderingQualityUltraRadioButton);
      this.RenderingQualityGroupBox.Controls.Add((Control) this.RenderingQualityHighRadioButton);
      this.RenderingQualityGroupBox.Controls.Add((Control) this.RenderingQualityMediumRadioButton);
      this.RenderingQualityGroupBox.Controls.Add((Control) this.RenderingQualityDescriptionLabel);
      this.RenderingQualityGroupBox.Controls.Add((Control) this.RenderingQualityLowRadioButton);
      this.RenderingQualityGroupBox.Controls.Add((Control) this.RenderingQualityAutoRadioButton);
      componentResourceManager.ApplyResources((object) this.RenderingQualityGroupBox, "RenderingQualityGroupBox");
      this.RenderingQualityGroupBox.Name = "RenderingQualityGroupBox";
      this.RenderingQualityGroupBox.TabStop = false;
      componentResourceManager.ApplyResources((object) this.RenderingQualityUltraRadioButton, "RenderingQualityUltraRadioButton");
      this.RenderingQualityUltraRadioButton.Name = "RenderingQualityUltraRadioButton";
      this.RenderingQualityUltraRadioButton.UseVisualStyleBackColor = true;
      this.RenderingQualityUltraRadioButton.CheckedChanged += new EventHandler(this.RenderingQualityUltraRadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.RenderingQualityHighRadioButton, "RenderingQualityHighRadioButton");
      this.RenderingQualityHighRadioButton.Name = "RenderingQualityHighRadioButton";
      this.RenderingQualityHighRadioButton.UseVisualStyleBackColor = true;
      this.RenderingQualityHighRadioButton.CheckedChanged += new EventHandler(this.RenderingQualityHighRadioButton_CheckedChanged_1);
      componentResourceManager.ApplyResources((object) this.RenderingQualityMediumRadioButton, "RenderingQualityMediumRadioButton");
      this.RenderingQualityMediumRadioButton.Name = "RenderingQualityMediumRadioButton";
      this.RenderingQualityMediumRadioButton.UseVisualStyleBackColor = true;
      this.RenderingQualityMediumRadioButton.CheckedChanged += new EventHandler(this.RenderingQualityMediumRadioButton_CheckedChanged_1);
      componentResourceManager.ApplyResources((object) this.RenderingQualityDescriptionLabel, "RenderingQualityDescriptionLabel");
      this.RenderingQualityDescriptionLabel.Name = "RenderingQualityDescriptionLabel";
      componentResourceManager.ApplyResources((object) this.RenderingQualityLowRadioButton, "RenderingQualityLowRadioButton");
      this.RenderingQualityLowRadioButton.Name = "RenderingQualityLowRadioButton";
      this.RenderingQualityLowRadioButton.UseVisualStyleBackColor = true;
      this.RenderingQualityLowRadioButton.CheckedChanged += new EventHandler(this.RenderingQualityHighRadioButton_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.RenderingQualityAutoRadioButton, "RenderingQualityAutoRadioButton");
      this.RenderingQualityAutoRadioButton.Checked = true;
      this.RenderingQualityAutoRadioButton.Name = "RenderingQualityAutoRadioButton";
      this.RenderingQualityAutoRadioButton.TabStop = true;
      this.RenderingQualityAutoRadioButton.UseVisualStyleBackColor = true;
      this.RenderingQualityAutoRadioButton.CheckedChanged += new EventHandler(this.RenderingQualityMediumRadioButton_CheckedChanged);
      this.ResolutionGroupBox.Controls.Add((Control) this.viewMode_WindowedBorderless);
      this.ResolutionGroupBox.Controls.Add((Control) this.viewMode_FullScreen);
      this.ResolutionGroupBox.Controls.Add((Control) this.viewMode_Windowed);
      this.ResolutionGroupBox.Controls.Add((Control) this.AspectRatioDesc);
      this.ResolutionGroupBox.Controls.Add((Control) this.resolutionComboBox1);
      componentResourceManager.ApplyResources((object) this.ResolutionGroupBox, "ResolutionGroupBox");
      this.ResolutionGroupBox.Name = "ResolutionGroupBox";
      this.ResolutionGroupBox.TabStop = false;
      componentResourceManager.ApplyResources((object) this.viewMode_WindowedBorderless, "viewMode_WindowedBorderless");
      this.viewMode_WindowedBorderless.Name = "viewMode_WindowedBorderless";
      this.viewMode_WindowedBorderless.UseVisualStyleBackColor = true;
      this.viewMode_WindowedBorderless.CheckedChanged += new EventHandler(this.viewMode_WindowedBorderless_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.viewMode_FullScreen, "viewMode_FullScreen");
      this.viewMode_FullScreen.Checked = true;
      this.viewMode_FullScreen.Name = "viewMode_FullScreen";
      this.viewMode_FullScreen.TabStop = true;
      this.viewMode_FullScreen.UseVisualStyleBackColor = true;
      this.viewMode_FullScreen.CheckedChanged += new EventHandler(this.viewMode_FullScreen_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.viewMode_Windowed, "viewMode_Windowed");
      this.viewMode_Windowed.Name = "viewMode_Windowed";
      this.viewMode_Windowed.UseVisualStyleBackColor = true;
      this.viewMode_Windowed.CheckedChanged += new EventHandler(this.viewMode_Windowed_CheckedChanged);
      componentResourceManager.ApplyResources((object) this.AspectRatioDesc, "AspectRatioDesc");
      this.AspectRatioDesc.Name = "AspectRatioDesc";
      this.resolutionComboBox1.DisplayMember = "1280x720";
      this.resolutionComboBox1.DropDownStyle = ComboBoxStyle.DropDownList;
      this.resolutionComboBox1.FormattingEnabled = true;
      this.resolutionComboBox1.Items.AddRange(new object[2]
      {
        (object) componentResourceManager.GetString("resolutionComboBox1.Items"),
        (object) componentResourceManager.GetString("resolutionComboBox1.Items1")
      });
      componentResourceManager.ApplyResources((object) this.resolutionComboBox1, "resolutionComboBox1");
      this.resolutionComboBox1.Name = "resolutionComboBox1";
      this.resolutionComboBox1.SelectedIndexChanged += new EventHandler(this.resolutionComboBox1_SelectedIndexChanged);
      this.TabControl.Controls.Add((Control) this.DisplayConfigurationTab);
      this.TabControl.Controls.Add((Control) this.ButtonIconsTab);
      this.TabControl.Controls.Add((Control) this.VoiceChatTab);
      componentResourceManager.ApplyResources((object) this.TabControl, "TabControl");
      this.TabControl.Name = "TabControl";
      this.TabControl.SelectedIndex = 0;
      this.TabControl.SelectedIndexChanged += new EventHandler(this.SelectedTabChange);
      this.ButtonIconsTab.Controls.Add((Control) this.ButtonIconTypeGroupBox);
      componentResourceManager.ApplyResources((object) this.ButtonIconsTab, "ButtonIconsTab");
      this.ButtonIconsTab.Name = "ButtonIconsTab";
      this.ButtonIconsTab.UseVisualStyleBackColor = true;
      this.ButtonIconTypeGroupBox.Controls.Add((Control) this.ControllerPictureBox);
      this.ButtonIconTypeGroupBox.Controls.Add((Control) this.ControllerOther);
      this.ButtonIconTypeGroupBox.Controls.Add((Control) this.ControllerXenon);
      this.ButtonIconTypeGroupBox.Controls.Add((Control) this.ButtonIconTypeLabel);
      componentResourceManager.ApplyResources((object) this.ButtonIconTypeGroupBox, "ButtonIconTypeGroupBox");
      this.ButtonIconTypeGroupBox.Name = "ButtonIconTypeGroupBox";
      this.ButtonIconTypeGroupBox.TabStop = false;
      componentResourceManager.ApplyResources((object) this.ControllerPictureBox, "ControllerPictureBox");
      this.ControllerPictureBox.Name = "ControllerPictureBox";
      this.ControllerPictureBox.TabStop = false;
      componentResourceManager.ApplyResources((object) this.ControllerOther, "ControllerOther");
      this.ControllerOther.Name = "ControllerOther";
      this.ControllerOther.TabStop = true;
      this.ControllerOther.UseVisualStyleBackColor = true;
      componentResourceManager.ApplyResources((object) this.ControllerXenon, "ControllerXenon");
      this.ControllerXenon.Checked = true;
      this.ControllerXenon.Name = "ControllerXenon";
      this.ControllerXenon.TabStop = true;
      this.ControllerXenon.UseVisualStyleBackColor = true;
      componentResourceManager.ApplyResources((object) this.ButtonIconTypeLabel, "ButtonIconTypeLabel");
      this.ButtonIconTypeLabel.Name = "ButtonIconTypeLabel";
      componentResourceManager.ApplyResources((object) this, "$this");
      this.AutoScaleMode = AutoScaleMode.Font;
      this.Controls.Add((Control) this.CancelButton1);
      this.Controls.Add((Control) this.OkButton1);
      this.Controls.Add((Control) this.TabControl);
      this.Name = nameof (GameSettingsForm);
      this.Load += new EventHandler(this.GameSettingsForm_Load);
      this.VoiceChatTab.ResumeLayout(false);
      this.MixModeGroupBox.ResumeLayout(false);
      this.MixModeGroupBox.PerformLayout();
      this.VoiceChatGroupBoxTEST.ResumeLayout(false);
      this.VoiceChatGroupBoxTEST.PerformLayout();
      this.DisplayConfigurationTab.ResumeLayout(false);
      this.DirectX12GroupBox.ResumeLayout(false);
      this.groupBox1.ResumeLayout(false);
      this.groupBox1.PerformLayout();
      this.LockGameGroupBox.ResumeLayout(false);
      this.LockGameGroupBox.PerformLayout();
      this.RenderingQualityGroupBox.ResumeLayout(false);
      this.RenderingQualityGroupBox.PerformLayout();
      this.ResolutionGroupBox.ResumeLayout(false);
      this.ResolutionGroupBox.PerformLayout();
      this.TabControl.ResumeLayout(false);
      this.ButtonIconsTab.ResumeLayout(false);
      this.ButtonIconTypeGroupBox.ResumeLayout(false);
      this.ButtonIconTypeGroupBox.PerformLayout();
      ((ISupportInitialize) this.ControllerPictureBox).EndInit();
      this.ResumeLayout(false);
    }

    private enum eMixMode
    {
      MIXMODE_STEREO,
      MIXMODE_5_1,
      MIXMODE_7_1,
    }

    private enum eVSyncRate
    {
      VSYNC_DISABLED,
      VSYNC_60HZ,
      VSYNC_30HZ,
    }

    private enum eMSAA
    {
      MSAA_AUTO,
      MSAA_OFF,
      MSAA_TWOPASS,
      MSAA_FOURPASS,
    }

    private enum eDirectxMode
    {
      DXSELECT_AUTO,
      DXSELECT_11,
      DXSELECT_12,
    }

    private class NameEntry
    {
      public string mOffenceName;
      public string mDefenseName;

      public NameEntry(string a, string b)
      {
        ResourceManager resourceManager = new ResourceManager("fifasetup_csharp.Resources.StringResource", Assembly.GetExecutingAssembly());
        this.mOffenceName = resourceManager.GetString(a);
        this.mDefenseName = resourceManager.GetString(b);
      }
    }

    private class Event
    {
      private string eventName;
      private string controllerName;

      public Event(StringBuilder eventString, StringBuilder controllerString)
      {
        this.eventName = eventString.ToString();
        this.controllerName = controllerString.ToString();
      }
    }
  }
}
